# The major and minor releases contain a full tarball.  Patch releases, however,
# contain only the parts that have changed, typically just the sources
# directory.  Use this to set up everything appropriately.
%global minorver 2.3
%global patchrel 3

%global debug_package %{nil}

Summary:        Automated theorem prover including linear arithmetic
Name:           alt-ergo
Version:        %{minorver}.%{patchrel}
Release:        %mkrel 1
Group:          Sciences/Computer science
# The project as a whole is Apache-2.0.
# The AB-Why3 plugin is LGPL-2.1-only WITH OCaml-LGPL-linking-exception
License:       Apache-2.0 AND LGPL-2.1-only WITH OCaml-LGPL-linking-exception
URL:           https://alt-ergo.ocamlpro.com/
# The patch releases contain only the sources directory.  The other files come
# from the minor releases.
Source0:       https://alt-ergo.ocamlpro.com/http/%{name}-free-%{minorver}.0/%{name}-free-%{minorver}.0.tar.gz
%if 0%{?patchrel} > 0
Source1:       https://alt-ergo.ocamlpro.com/http/%{name}-free-%{version}/%{name}-free-%{version}.tar.gz
%endif
Source4:       %{name}.metainfo.xml
# Do not use the deprecated Pervasives interface
Patch0:                %{name}-pervasives.patch
# Adapt to recent changes in psmt2-frontend
Patch1:                %{name}-psmt2-frontend.patch
# Temporarily use the menhir table backend instead of the code backend for the
# AB plugin.  Menhir is unable to infer types with the current code and layout.
# Check each new release to see if this is still necessary.
Patch2:         %{name}-menhir.patch
# Fedora does not need the forward compatibility seq and stdlib-shims packages
Patch3:         %{name}-forward-compat.patch
# Dune 3 eliminated the external-lib-deps command
Patch4:         %{name}-dune3.patch

BuildRequires:	make
BuildRequires:	ocaml >= 4.04.0
BuildRequires:	ocaml-dune
BuildRequires:	ocaml-menhir
BuildRequires:	ocaml-num-devel
BuildRequires:	ocaml-ocplib-simplex-devel >= 0.4
BuildRequires:	ocaml-psmt2-frontend-devel >= 0.2
BuildRequires:	ocaml-zarith-devel
BuildRequires:	ocaml-zip-devel

%global _desc %{expand:
Alt-Ergo is an automated theorem prover implemented in OCaml. It is
based on CC(X) - a congruence closure algorithm parameterized by an
equational theory X. This algorithm is reminiscent of the Shostak
algorithm. Currently CC(X) is instantiated by the theory of linear
arithmetics. Alt-Ergo also contains a home made SAT-solver and an
instantiation mechanism by which it fully supports quantifiers.}

%description %_desc

%package -n ocaml-alt-ergo-parsers
Summary:	Parser library used by the Alt-Ergo SMT solver
License:	Apache-2.0
Requires:	ocaml-alt-ergo-lib%{?_isa} = %{version}-%{release}

%description -n ocaml-alt-ergo-parsers %_desc

This package contains the parser library used by the Alt-Ergo SMT solver.

%package -n ocaml-alt-ergo-parsers-devel
Summary:	Development files for ocaml-alt-ergo-parsers
License:	Apache-2.0
Requires:	ocaml-alt-ergo-parsers%{?_isa} = %{version}-%{release}
Requires:	ocaml-alt-ergo-lib-devel%{?_isa} = %{version}-%{release}
Requires:	ocaml-psmt2-frontend-devel%{?_isa}
Requires:	ocaml-zip-devel%{?_isa}

%description -n ocaml-alt-ergo-parsers-devel %_desc

This package contains development files needed to build applications
that use the Alt-Ergo parser library.

%package -n ocaml-alt-ergo-lib
Summary:	Automated theorem prover library
License:	Apache-2.0

%description -n ocaml-alt-ergo-lib %_desc

This package is the core of Alt-Ergo as an OCaml library.

%package -n ocaml-alt-ergo-lib-devel
Summary:	Development files for ocaml-alt-ergo-lib
License:	Apache-2.0
Requires:	ocaml-alt-ergo-lib%{?_isa} = %{version}-%{release}
Requires:	ocaml-num-devel%{?_isa}
Requires:	ocaml-ocplib-simplex-devel%{?_isa}
Requires:	ocaml-zarith-devel%{?_isa}

%description -n ocaml-alt-ergo-lib-devel %_desc

This package contains development files needed to build applications
that use the Alt-Ergo library.

%prep
%autosetup -n %{name}-%{minorver}.0-free -N 

%if 0%{?patchrel} > 0
# See above.  Replace the minor release sources with the patch release sources.
rm -rf sources
tar xf %{SOURCE1}
%endif

%autopatch -p1
cd sources

# Unzip an example
cd examples/AB-Why3-plugin
unzip p4_34.why.zip
rm p4_34.why.zip
cd -

# This requires gtksourceview2 we don't have anymore
rm -f altgr-ergo*
rm -rf tools/gui/

%build
cd sources
# This is not an autoconf-generated script.  Do NOT use %%configure.
./configure --prefix=%{_prefix} --libdir=%{ocamldir} --sharedir=%{ocamldir}
make lib
make bin
make plugins

%install
cd sources
#make_install DUNE_FLAGS="-p alt-ergo,alt-ergo-lib,alt-ergo-parsers,alt-ergo-lib-free,alt-ergo-free,alt-ergo-parsers-free"
%make_install DUNE_FLAGS="-p alt-ergo,alt-ergo-lib,alt-ergo-parsers,alt-ergo-lib-free,alt-ergo-free,alt-ergo-parsers-free"

# We do not want the ml files
find %{buildroot}%{ocamldir} -name \*.ml -delete

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

# Install the man page
mkdir -p %{buildroot}%{_mandir}/man1
cp -p doc/alt-ergo.1 %{buildroot}%{_mandir}/man1

# The install target in the Makefile puts these in the wrong place
mv %{buildroot}%{_datadir}/alt-ergo/{plugins,preludes} \
   %{buildroot}%{ocamldir}/alt-ergo
rmdir %{buildroot}%{_datadir}/alt-ergo

%check
cd sources
%dune_check

%files
%doc README.md sources/CHANGES sources/examples publications/*.pdf
%{_bindir}/%{name}
%{_mandir}/man1/alt-ergo.1.*
%{ocamldir}/%{name}/
%{ocamldir}/%{name}-free/

%files -n ocaml-%{name}-parsers
%dir %{ocamldir}/%{name}-parsers/
%{ocamldir}/%{name}-parsers/META
%{ocamldir}/%{name}-parsers/*.cma
%{ocamldir}/%{name}-parsers/*.cmi
%ifarch %{ocaml_native_compiler}
%{ocamldir}/%{name}-parsers/*.cmxs
%endif
%{ocamldir}/%{name}-parsers-free/

%files -n ocaml-%{name}-parsers-devel
%{ocamldir}/%{name}-parsers/dune-package
%{ocamldir}/%{name}-parsers/opam
%ifarch %{ocaml_native_compiler}
%{ocamldir}/%{name}-parsers/*.a
%{ocamldir}/%{name}-parsers/*.cmx
%{ocamldir}/%{name}-parsers/*.cmxa
%endif
%{ocamldir}/%{name}-parsers/*.mli
%{ocamldir}/%{name}-parsers/*.cmt
%{ocamldir}/%{name}-parsers/*.cmti

%files -n ocaml-%{name}-lib
%dir %{ocamldir}/%{name}-lib/
%license LGPL-License.txt LICENSE.md License.OCamlPro
%{ocamldir}/%{name}-lib/META
%{ocamldir}/%{name}-lib/*.cma
%{ocamldir}/%{name}-lib/*.cmi
%ifarch %{ocaml_native_compiler}
%{ocamldir}/%{name}-lib/*.cmxs
%endif
%{ocamldir}/%{name}-lib-free/

%files -n ocaml-%{name}-lib-devel
%{ocamldir}/%{name}-lib/dune-package
%{ocamldir}/%{name}-lib/opam
%ifarch %{ocaml_native_compiler}
%{ocamldir}/%{name}-lib/*.a
%{ocamldir}/%{name}-lib/*.cmx
%{ocamldir}/%{name}-lib/*.cmxa
%endif
%{ocamldir}/%{name}-lib/*.mli
%{ocamldir}/%{name}-lib/*.cmt
%{ocamldir}/%{name}-lib/*.cmti



%changelog
* Sun Mar 19 2023 pterjan <pterjan> 2.3.3-1.mga9
+ Revision: 1949747
- Update to 2.3.3 and partially sync with Fedora
- Disable GUI as it needs gtksourceview2 we no longer have

* Sun Jan 08 2023 daviddavid <daviddavid> 2.2.0-18.mga9
+ Revision: 1931573
- rebuild for ocaml-zarith change

* Thu May 19 2022 pterjan <pterjan> 2.2.0-17.mga9
+ Revision: 1859000
- Rebuild for OCaml 4.14

* Wed Apr 06 2022 umeabot <umeabot> 2.2.0-16.mga9
+ Revision: 1845914
- Mageia 9 Mass Rebuild

* Thu Oct 14 2021 tv <tv> 2.2.0-15.mga9
+ Revision: 1751384
- Rebuild for ocaml 4.13.1

* Fri Mar 26 2021 tv <tv> 2.2.0-14.mga9
+ Revision: 1710561
- Do not Require private ocaml interfaces that we don't Provide
  (thus fixing installation)

* Mon Mar 22 2021 tv <tv> 2.2.0-12.mga9
+ Revision: 1707991
- Rebuild for ocaml 4.12
- rebuild for ocaml-4.12

* Wed Aug 19 2020 martinw <martinw> 2.2.0-10.mga8
+ Revision: 1615508
- use free (ASL 2.0 licensed) version
- drop GUI package (needs obsolete gtksourceview2)

* Fri Feb 28 2020 umeabot <umeabot> 2.2.0-9.mga8
+ Revision: 1551478
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 2.2.0-8.mga8
+ Revision: 1544291
- Mageia 8 Mass Rebuild

* Fri Jan 24 2020 tv <tv> 2.2.0-7.mga8
+ Revision: 1482733
- rebuild for ocaml-4.10
+ wally <wally>
- replace deprecated %%configure2_5x
+ daviddavid <daviddavid>
- rebuild for new ocaml-psmt2-frontend 0.2

* Thu Oct 25 2018 daviddavid <daviddavid> 2.2.0-5.mga7
+ Revision: 1325199
- rebuild for new ocaml 4.07.1

* Fri Sep 21 2018 umeabot <umeabot> 2.2.0-4.mga7
+ Revision: 1294308
- Mageia 7 Mass Rebuild

* Tue May 08 2018 kekepower <kekepower> 2.2.0-3.mga7
+ Revision: 1227647
- Fix the global exclude

* Tue May 08 2018 kekepower <kekepower> 2.2.0-2.mga7
+ Revision: 1227641
- Exclude bogus requires

* Sun Apr 29 2018 kekepower <kekepower> 2.2.0-1.mga7
+ Revision: 1223246
- BR ocaml-psmt2-frontend
- Update to version 2.2.0

* Sun Mar 25 2018 daviddavid <daviddavid> 2.1.0-3.mga7
+ Revision: 1212412
- rebuild for new ocaml-zarith 1.7

* Fri Mar 23 2018 kekepower <kekepower> 2.1.0-2.mga7
+ Revision: 1211584
- Rebuild on arm

* Fri Mar 23 2018 kekepower <kekepower> 2.1.0-1.mga7
+ Revision: 1211568
- Add LGPL license
- Fix file list
- Add BR for menhir
- Update to version 2.1.0

* Tue Feb 06 2018 daviddavid <daviddavid> 1.30-2.mga7
+ Revision: 1199171
- add BR ocaml-num-devel

* Sat Jan 21 2017 daviddavid <daviddavid> 1.30-1.mga6
+ Revision: 1082661
- new version: 1.30
- add BRs ocaml-camlzip-devel and ocaml-camlzip-devel

* Sun Sep 25 2016 pterjan <pterjan> 1.01-2.mga6
+ Revision: 1056198
- Rebuild for fix in ocaml

* Sat Mar 26 2016 daviddavid <daviddavid> 1.01-1.mga6
+ Revision: 995605
- new version: 1.01

* Mon Jan 25 2016 daviddavid <daviddavid> 0.99.1-1.mga6
+ Revision: 927350
- new version: 0.99.1

* Wed Oct 15 2014 umeabot <umeabot> 0.95.2-4.mga5
+ Revision: 743440
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.95.2-3.mga5
+ Revision: 677745
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 0.95.2-2.mga4
+ Revision: 543622
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 malo <malo> 0.95.2-1.mga4
+ Revision: 498662
- new version 0.95.2

* Fri May 31 2013 malo <malo> 0.95.1-1.mga4
+ Revision: 433869
- new version 0.95.1

* Fri Jan 11 2013 umeabot <umeabot> 0.94-3.mga3
+ Revision: 345522
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 04 2012 malo <malo> 0.94-2.mga3
+ Revision: 326565
+ rebuild (emptylog)

* Tue Dec 04 2012 malo <malo> 0.94-1.mga3
+ Revision: 326543
- change BR to ocaml-compiler

* Sun Dec 11 2011 malo <malo> 0.94-1.mga2
+ Revision: 180489
- new version 0.94
- missing Requires gtksourceview2
- fixing install of source.lang and ocaml lib

* Sat Nov 05 2011 malo <malo> 0.93-1.mga2
+ Revision: 163891
- imported package alt-ergo

